==> eam-wshub-proxyclient-11.4-6-sources.jar: net/datastream/schemas/mp_functions/mp0118_getgridheaderdata_001/FUNCTION_REQUEST_INFO.java <==

package net.datastream.schemas.mp_functions.mp0118_getgridheaderdata_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_functions.gridrequest.ADDON_FILTER;
import net.datastream.schemas.mp_functions.gridrequest.ADDON_SORT;
import net.datastream.schemas.mp_functions.gridrequest.DATASPY;
import net.datastream.schemas.mp_functions.gridrequest.GRID;
import net.datastream.schemas.mp_functions.gridrequest.GRID_TYPE;
import net.datastream.schemas.mp_functions.gridrequest.LOV;
import net.datastream.schemas.mp_functions.gridrequest.MULTIADDON_FILTERS;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/GridRequest}GRID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/GridRequest}ADDON_SORT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/GridRequest}ADDON_FILTER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/GridRequest}MULTIADDON_FILTERS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/GridRequest}GRID_TYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/GridRequest}DATASPY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/GridRequest}LOV" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="REQUEST_TYPE" type="{http://schemas.datastream.net/MP_functions/MP0118_GetGridHeaderData_001}FUNCTION_REQUEST_TYPE" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "grid",
    "addon_SORT",
    "addon_FILTER",
    "multiaddon_FILTERS",
    "grid_TYPE",
    "dataspy",
    "lov"
})
@XmlRootElement(name = "FUNCTION_REQUEST_INFO")
public class FUNCTION_REQUEST_INFO {

    @XmlElement(name = "GRID", namespace = "http://schemas.datastream.net/MP_functions/GridRequest", required = true)
    protected GRID grid;
    @XmlElement(name = "ADDON_SORT", namespace = "http://schemas.datastream.net/MP_functions/GridRequest")
    protected ADDON_SORT addon_SORT;
    @XmlElement(name = "ADDON_FILTER", namespace = "http://schemas.datastream.net/MP_functions/GridRequest")
    protected ADDON_FILTER addon_FILTER;
    @XmlElement(name = "MULTIADDON_FILTERS", namespace = "http://schemas.datastream.net/MP_functions/GridRequest")
    protected MULTIADDON_FILTERS multiaddon_FILTERS;
    @XmlElement(name = "GRID_TYPE", namespace = "http://schemas.datastream.net/MP_functions/GridRequest", required = true)
    protected GRID_TYPE grid_TYPE;
    @XmlElement(name = "DATASPY", namespace = "http://schemas.datastream.net/MP_functions/GridRequest")
    protected DATASPY dataspy;
    @XmlElement(name = "LOV", namespace = "http://schemas.datastream.net/MP_functions/GridRequest")
    protected LOV lov;
    @XmlAttribute(name = "REQUEST_TYPE")
    protected FUNCTION_REQUEST_TYPE request_TYPE;

    /**
     * Obtient la valeur de la propriété grid.
     * 
     * @return
     *     possible object is
     *     {@link GRID }
     *     
     */
    public GRID getGRID() {
        return grid;
    }

    /**
     * Définit la valeur de la propriété grid.
     * 
     * @param value
     *     allowed object is
     *     {@link GRID }
     *     
     */
    public void setGRID(GRID value) {
        this.grid = value;
    }

    /**
     * Obtient la valeur de la propriété addon_SORT.
     * 
     * @return
     *     possible object is
     *     {@link ADDON_SORT }
     *     
     */
    public ADDON_SORT getADDON_SORT() {
        return addon_SORT;
    }

    /**
     * Définit la valeur de la propriété addon_SORT.
     * 
     * @param value
     *     allowed object is
     *     {@link ADDON_SORT }
     *     
     */
    public void setADDON_SORT(ADDON_SORT value) {
        this.addon_SORT = value;
    }

    /**
     * Obtient la valeur de la propriété addon_FILTER.
     * 
     * @return
     *     possible object is
     *     {@link ADDON_FILTER }
     *     
     */
    public ADDON_FILTER getADDON_FILTER() {
        return addon_FILTER;
    }

    /**
     * Définit la valeur de la propriété addon_FILTER.
     * 
     * @param value
     *     allowed object is
     *     {@link ADDON_FILTER }
     *     
     */
    public void setADDON_FILTER(ADDON_FILTER value) {
        this.addon_FILTER = value;
    }

    /**
     * Obtient la valeur de la propriété multiaddon_FILTERS.
     * 
     * @return
     *     possible object is
     *     {@link MULTIADDON_FILTERS }
     *     
     */
    public MULTIADDON_FILTERS getMULTIADDON_FILTERS() {
        return multiaddon_FILTERS;
    }

    /**
     * Définit la valeur de la propriété multiaddon_FILTERS.
     * 
     * @param value
     *     allowed object is
     *     {@link MULTIADDON_FILTERS }
     *     
     */
    public void setMULTIADDON_FILTERS(MULTIADDON_FILTERS value) {
        this.multiaddon_FILTERS = value;
    }

    /**
     * Obtient la valeur de la propriété grid_TYPE.
     * 
     * @return
     *     possible object is
     *     {@link GRID_TYPE }
     *     
     */
    public GRID_TYPE getGRID_TYPE() {
        return grid_TYPE;
    }

    /**
     * Définit la valeur de la propriété grid_TYPE.
     * 
     * @param value
     *     allowed object is
     *     {@link GRID_TYPE }
     *     
     */
    public void setGRID_TYPE(GRID_TYPE value) {
        this.grid_TYPE = value;
    }

    /**
     * Obtient la valeur de la propriété dataspy.
     * 
     * @return
     *     possible object is
     *     {@link DATASPY }
     *     
     */
    public DATASPY getDATASPY() {
        return dataspy;
    }

    /**
     * Définit la valeur de la propriété dataspy.
     * 
     * @param value
     *     allowed object is
     *     {@link DATASPY }
     *     
     */
    public void setDATASPY(DATASPY value) {
        this.dataspy = value;
    }

    /**
     * Obtient la valeur de la propriété lov.
     * 
     * @return
     *     possible object is
     *     {@link LOV }
     *     
     */
    public LOV getLOV() {
        return lov;
    }

    /**
     * Définit la valeur de la propriété lov.
     * 
     * @param value
     *     allowed object is
     *     {@link LOV }
     *     
     */
    public void setLOV(LOV value) {
        this.lov = value;
    }

    /**
     * Obtient la valeur de la propriété request_TYPE.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTION_REQUEST_TYPE }
     *     
     */
    public FUNCTION_REQUEST_TYPE getREQUEST_TYPE() {
        return request_TYPE;
    }

    /**
     * Définit la valeur de la propriété request_TYPE.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTION_REQUEST_TYPE }
     *     
     */
    public void setREQUEST_TYPE(FUNCTION_REQUEST_TYPE value) {
        this.request_TYPE = value;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_functions/mp0118_getgridheaderdata_001/FUNCTION_REQUEST_INFO.java <==

package net.datastream.schemas.mp_functions.mp0118_getgridheaderdata_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_functions.gridrequest.ADDON_FILTER;
import net.datastream.schemas.mp_functions.gridrequest.ADDON_SORT;
import net.datastream.schemas.mp_functions.gridrequest.DATASPY;
import net.datastream.schemas.mp_functions.gridrequest.GRID;
import net.datastream.schemas.mp_functions.gridrequest.GRID_TYPE;
import net.datastream.schemas.mp_functions.gridrequest.LOV;
import net.datastream.schemas.mp_functions.gridrequest.MULTIADDON_FILTERS;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_functions/GridRequest}GRID"/>
 *         <element ref="{http://schemas.datastream.net/MP_functions/GridRequest}ADDON_SORT" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_functions/GridRequest}ADDON_FILTER" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_functions/GridRequest}MULTIADDON_FILTERS" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_functions/GridRequest}GRID_TYPE"/>
 *         <element ref="{http://schemas.datastream.net/MP_functions/GridRequest}DATASPY" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_functions/GridRequest}LOV" minOccurs="0"/>
 *       </sequence>
 *       <attribute name="REQUEST_TYPE" type="{http://schemas.datastream.net/MP_functions/MP0118_GetGridHeaderData_001}FUNCTION_REQUEST_TYPE" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "grid",
    "addon_SORT",
    "addon_FILTER",
    "multiaddon_FILTERS",
    "grid_TYPE",
    "dataspy",
    "lov"
})
@XmlRootElement(name = "FUNCTION_REQUEST_INFO")
public class FUNCTION_REQUEST_INFO {

    @XmlElement(name = "GRID", namespace = "http://schemas.datastream.net/MP_functions/GridRequest", required = true)
    protected GRID grid;
    @XmlElement(name = "ADDON_SORT", namespace = "http://schemas.datastream.net/MP_functions/GridRequest")
    protected ADDON_SORT addon_SORT;
    @XmlElement(name = "ADDON_FILTER", namespace = "http://schemas.datastream.net/MP_functions/GridRequest")
    protected ADDON_FILTER addon_FILTER;
    @XmlElement(name = "MULTIADDON_FILTERS", namespace = "http://schemas.datastream.net/MP_functions/GridRequest")
    protected MULTIADDON_FILTERS multiaddon_FILTERS;
    @XmlElement(name = "GRID_TYPE", namespace = "http://schemas.datastream.net/MP_functions/GridRequest", required = true)
    protected GRID_TYPE grid_TYPE;
    @XmlElement(name = "DATASPY", namespace = "http://schemas.datastream.net/MP_functions/GridRequest")
    protected DATASPY dataspy;
    @XmlElement(name = "LOV", namespace = "http://schemas.datastream.net/MP_functions/GridRequest")
    protected LOV lov;
    @XmlAttribute(name = "REQUEST_TYPE")
    protected FUNCTION_REQUEST_TYPE request_TYPE;

    /**
     * Gets the value of the grid property.
     * 
     * @return
     *     possible object is
     *     {@link GRID }
     *     
     */
    public GRID getGRID() {
        return grid;
    }

    /**
     * Sets the value of the grid property.
     * 
     * @param value
     *     allowed object is
     *     {@link GRID }
     *     
     */
    public void setGRID(GRID value) {
        this.grid = value;
    }

    /**
     * Gets the value of the addon_SORT property.
     * 
     * @return
     *     possible object is
     *     {@link ADDON_SORT }
     *     
     */
    public ADDON_SORT getADDON_SORT() {
        return addon_SORT;
    }

    /**
     * Sets the value of the addon_SORT property.
     * 
     * @param value
     *     allowed object is
     *     {@link ADDON_SORT }
     *     
     */
    public void setADDON_SORT(ADDON_SORT value) {
        this.addon_SORT = value;
    }

    /**
     * Gets the value of the addon_FILTER property.
     * 
     * @return
     *     possible object is
     *     {@link ADDON_FILTER }
     *     
     */
    public ADDON_FILTER getADDON_FILTER() {
        return addon_FILTER;
    }

    /**
     * Sets the value of the addon_FILTER property.
     * 
     * @param value
     *     allowed object is
     *     {@link ADDON_FILTER }
     *     
     */
    public void setADDON_FILTER(ADDON_FILTER value) {
        this.addon_FILTER = value;
    }

    /**
     * Gets the value of the multiaddon_FILTERS property.
     * 
     * @return
     *     possible object is
     *     {@link MULTIADDON_FILTERS }
     *     
     */
    public MULTIADDON_FILTERS getMULTIADDON_FILTERS() {
        return multiaddon_FILTERS;
    }

    /**
     * Sets the value of the multiaddon_FILTERS property.
     * 
     * @param value
     *     allowed object is
     *     {@link MULTIADDON_FILTERS }
     *     
     */
    public void setMULTIADDON_FILTERS(MULTIADDON_FILTERS value) {
        this.multiaddon_FILTERS = value;
    }

    /**
     * Gets the value of the grid_TYPE property.
     * 
     * @return
     *     possible object is
     *     {@link GRID_TYPE }
     *     
     */
    public GRID_TYPE getGRID_TYPE() {
        return grid_TYPE;
    }

    /**
     * Sets the value of the grid_TYPE property.
     * 
     * @param value
     *     allowed object is
     *     {@link GRID_TYPE }
     *     
     */
    public void setGRID_TYPE(GRID_TYPE value) {
        this.grid_TYPE = value;
    }

    /**
     * Gets the value of the dataspy property.
     * 
     * @return
     *     possible object is
     *     {@link DATASPY }
     *     
     */
    public DATASPY getDATASPY() {
        return dataspy;
    }

    /**
     * Sets the value of the dataspy property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATASPY }
     *     
     */
    public void setDATASPY(DATASPY value) {
        this.dataspy = value;
    }

    /**
     * Gets the value of the lov property.
     * 
     * @return
     *     possible object is
     *     {@link LOV }
     *     
     */
    public LOV getLOV() {
        return lov;
    }

    /**
     * Sets the value of the lov property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOV }
     *     
     */
    public void setLOV(LOV value) {
        this.lov = value;
    }

    /**
     * Gets the value of the request_TYPE property.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTION_REQUEST_TYPE }
     *     
     */
    public FUNCTION_REQUEST_TYPE getREQUEST_TYPE() {
        return request_TYPE;
    }

    /**
     * Sets the value of the request_TYPE property.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTION_REQUEST_TYPE }
     *     
     */
    public void setREQUEST_TYPE(FUNCTION_REQUEST_TYPE value) {
        this.request_TYPE = value;
    }

}
